%define upstream_name    Crypt-Primes
%define upstream_version 0.50

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 10

Summary:    Provable Prime Number Generator suitable for Cryptographic Application
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    ftp://ftp.perl.org/pub/CPAN/modules/by-module/Crypt/%{upstream_name}-%{upstream_version}.tar.bz2
Patch0:		Crypt-Primes-0.50-more-stack.patch

BuildRequires:  perl(Crypt::Random)
BuildArch:      noarch


%description
This module implements Ueli Maurer's algorithm for
generating large provable primes and secure parameters
for public-key cryptosystems. The generated primes are
almost uniformly distributed over the set of primes of
the specified bitsize and expected time for generation
is less than the time required for generating a
pseudo-prime of the same size with Miller-Rabin tests.
Detailed description and running time analysis of the
algorithm can be found in Maurer's paper[1].

Crypt::Primes is a pure perl implementation. It uses
Math::Pari for multiple precision integer arithmetic
and number theoretic functions. Random numbers are
gathered with Crypt::Random, a perl interface to
/dev/u?random devices found on most modern Unix operating
systems.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

# Allocate more stack for tests to avoid intermittent build failures
%patch0

%build
CFLAGS="$RPM_OPT_FLAGS" echo | %{__perl} Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%make_install

%files
%doc README
%{_bindir}/largeprimes
%{perl_vendorlib}/*
%{_mandir}/*/*


%changelog
* Wed May 27 2020 tv <tv> 0.500.0-10.mga8
+ Revision: 1588170
- Allocate more stack for t/genprime*.t to avoid intermittent build failures
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%makeinstall_std

* Wed Sep 19 2018 umeabot <umeabot> 0.500.0-8.mga7
+ Revision: 1266802
- Mageia 7 Mass Rebuild

* Sat Jun 18 2016 pterjan <pterjan> 0.500.0-7.mga6
+ Revision: 1024570
- Rebuild for perl 5.22.2

* Mon Feb 08 2016 umeabot <umeabot> 0.500.0-6.mga6
+ Revision: 943525
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.500.0-5.mga5
+ Revision: 744612
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.500.0-4.mga5
+ Revision: 684053
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 0.500.0-3.mga4
+ Revision: 510330
- Mageia 4 Mass Rebuild

* Sun Jan 13 2013 umeabot <umeabot> 0.500.0-2.mga3
+ Revision: 364926
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Jan 21 2011 jquelin <jquelin> 0.500.0-1.mga1
+ Revision: 28442
- mageia rebuild
- imported package perl-Crypt-Primes

